@@ -19,6 +19,7 @@ def do_ai_auto(Testk_data, clientinfo):
     自动化执行AI测试用例
     """
     startAt = 0
+    webapiClient(clientinfo).intentdetaillist_cookiecheck()
     try:
 
         # 判断Testsuitelink中是否包含https://
@@ -102,6 +103,7 @@ def do_ai_auto(Testk_data, clientinfo):
                 runs = AilyLarkClient(clientinfo).create_ailysession_run(tenant_access_token, seseion_id)
                 time.sleep(4)
                 num = num + 1
+                time.sleep(4)
             return startAt, num
     except KeyError as ke:
         print(f"KeyError 发生: 数据中缺少必要的键，错误详情: {ke}")
@@ -212,39 +214,62 @@ def do_waterlevellineres_listassetspu(res, info,hardtype):
         info['label'] = [{'label': '', 'score': 0}]
         info['rt'] = False
         return info
-    if res["data"].get("AiBorrowAndUseResponseList") == None:
-        info['label'] = [{'label': '', 'score': 0},{'label': '', 'score': 0.8}]
-        info['rt'] = False
-        if info['exp']==[]:
-            info['rt'] = True
-        return info
-    reslist=res["data"]["AiBorrowAndUseResponseList"]
-    info['output']['用户输入/output']='requestId:'+res['requestId']
-    aaa ={}
-    # 判断res["body"]["Results"]不为空，空则：label0 label1 为空，label默认2级
-    if reslist:
-        # 取["Results"]下前2个结果，若只有1个结果，label1为空
-        if len(reslist) > 0:
-           for j in range(len(reslist)):
-               if hardtype==2:
-                   aaa = {'label': reslist[j]['AccessoryModelScope']['AccessoryModelInfo']['Name']['ValueZh'],
-                          'score': reslist[j]['Score']}
-                   info['label'].append(copy.deepcopy(aaa))
-               if hardtype == 1:
-                   aaa = {'label': reslist[j]['AssetModelScope']['SpuNameZh'] or reslist[j]['AssetModelScope']['NameZh']+reslist[j]['AssetModelScope']['ModelZh']+reslist[j]['AssetModelScope']['SpecificationZh'],
-                          'score': reslist[j]['Score']}
-                   info['label'].append(copy.deepcopy(aaa))
-        # 判断label0和label1是否为空，为空则：label默认2级
-        for a in range(len(info['exp'])):
-            if info['exp'][a]['label'] == info['label'][a]['label']:
+    info['output']['用户输出/output'] = 'requestId:' + res['requestId']
+    if hardtype != 100:
+        if res["data"].get("AiBorrowAndUseResponseList") == None:
+            info['label'] = [{'label': '', 'score': 0}, {'label': '', 'score': 0.8}]
+            info['rt'] = False
+            if info['exp'] == []:
                 info['rt'] = True
-            else:
-                info['rt'] = False
-                break
-    else:
-        info['label'] = info['label'] = [{'label': '', 'score': 0}, {'label': '', 'score': 0}]
-        info['rt'] = False
-    return info
+            return info
+        reslist = res["data"]["AiBorrowAndUseResponseList"]
+        aaa = {}
+        # 判断res["body"]["Results"]不为空，空则：label0 label1 为空，label默认2级
+        if reslist:
+            # 取["Results"]下前2个结果，若只有1个结果，label1为空
+            if len(reslist) > 0:
+                for j in range(len(reslist)):
+                    if hardtype == 2:
+                        aaa = {'label': reslist[j]['AccessoryModelScope']['AccessoryModelInfo']['Name']['ValueZh'],
+                               'score': reslist[j]['Score']}
+                        info['label'].append(copy.deepcopy(aaa))
+                    if hardtype == 1:
+                        aaa = {'label': reslist[j]['AssetModelScope']['SpuNameZh'] or reslist[j]['AssetModelScope'][
+                            'NameZh'] + reslist[j]['AssetModelScope']['ModelZh'] + reslist[j]['AssetModelScope'][
+                                            'SpecificationZh'],
+                               'score': reslist[j]['Score']}
+                        info['label'].append(copy.deepcopy(aaa))
+            # 判断label0和label1是否为空，为空则：label默认2级
+            info['rt'] = do_businessassertionrules(info['label'], info['exp'])
+        else:
+            info['label'] = [{'label': '', 'score': 0}, {'label': '', 'score': 0}]
+            info['rt'] = False
+        return info
+    elif hardtype == 100:
+        if res["data"].get("SoftwareApplyRecommendList") == None:
+            info['label'] = [{'label': '', 'score': 0}, {'label': '', 'score': 0.8}]
+            info['rt'] = False
+            if info['exp'] == []:
+                info['rt'] = True
+            return info
+        reslist = res["data"]["SoftwareApplyRecommendList"]
+        info['output']['用户输出/output'] = 'requestId:' + res['requestId']
+        aaa = {}
+        # 判断res["body"]["Results"]不为空，空则：label0 label1 为空，label默认2级
+        if reslist:
+            # 取["Results"]下前2个结果，若只有1个结果，label1为空
+            if len(reslist) > 0:
+                for j in range(len(reslist)):
+                    aaa = {'label': reslist[j]['Data']['Name']['ValueZh'],
+                           'score': reslist[j]['Score']}
+                    info['label'].append(copy.deepcopy(aaa))
+            # 判断label0和label1是否为空，为空则：label默认2级
+            info['rt'] = do_businessassertionrules(info['label'], info['exp'])
+        else:
+            info['label'] = [{'label': '', 'score': 0}, {'label': '', 'score': 0}]
+            info['rt'] = False
+        return info
+
 
 def do_waterlevellineres_listassetspu_pre(res, info,hardtype):
     """
@@ -302,7 +327,8 @@ def do_waterlevellineres_sr(res, info,hardtype):
         if info['exp'][0]['label']=='':
             info['rt'] = True
         return info
-    reslist=res["data"]["AssetModels"]
+    # reslist=res["data"]["AssetModels"]
+    reslist = res["data"]["AiBorrowAndUseResponseList"]
     aaa ={}
     # 判断res["body"]["Results"]不为空，空则：label0 label1 为空，label默认2级
     if reslist:
@@ -400,13 +426,13 @@ def do_scenereview_list(collections,data,score_threshold):
             if i['content'] == j['用户输入/userInput']:
                 info['input']['用户输入/userInput'] = i['ext']['output']
                 info['output']['用户输入/output'] = j['用户输入/userInput']
-                if i['ext']['BPO标注-AP-资产名称'] == j['llm关键词']:
+                if i['ext']['资产名称'] == j['llm关键词']:
                     info['rt'] = True
                     info['label'] = [{'label': str(j['llm关键词']), 'score': score_threshold}]
                 else:
                     info['rt'] = False
-                    info['label'] = [{'label': str(i['ext']['BPO标注-AP-资产名称']), 'score': score_threshold}]
-                info['exp'] = [{'label': str(i['ext']['BPO标注-AP-资产名称']), 'score': score_threshold}]
+                    info['label'] = [{'label': str(i['ext']['资产名称']), 'score': score_threshold}]
+                info['exp'] = [{'label': str(i['ext']['资产名称']), 'score': score_threshold}]
                 info['artificial'] = info['exp']
     info_list.append(copy.deepcopy(info))
     return info_list
@@ -432,15 +458,15 @@ def do_waterlevelline_autotest(collections, clientinfo, score_threshold):
     }
     a =0
     for i in collections:
-        info['input']['用户输入/userInput'] = i['ext']['BPO标注-AP-资产名称']
-        info['output']['用户输入/output'] = i['ext']['BPO标注-AP-资产名称']
+        info['input']['用户输入/userInput'] = i['ext']['资产名称']
+        info['output']['用户输入/output'] = i['ext']['资产名称']
         info['exp'] = []
-        for j in [i['ext']['BPO标注-AP-资产型号'], i['ext'].get('BPO标注-AP-资产型号1'),i['ext'].get('BPO标注-AP-资产型号2'),i['ext'].get('BPO标注-AP-资产型号3'),i['ext'].get('BPO标注-AP-资产型号4'),i['ext'].get('BPO标注-AP-资产型号5'),i['ext'].get('BPO标注-AP-资产型号6'),i['ext'].get('BPO标注-AP-资产型号7'),i['ext'].get('BPO标注-AP-资产型号8'),i['ext'].get('BPO标注-AP-资产型号9'),i['ext'].get('BPO标注-AP-资产型号10')]:
+        for j in [i['ext']['资产型号'], i['ext'].get('资产型号1'),i['ext'].get('资产型号2'),i['ext'].get('资产型号3'),i['ext'].get('资产型号4'),i['ext'].get('资产型号5'),i['ext'].get('资产型号6'),i['ext'].get('资产型号7'),i['ext'].get('资产型号8'),i['ext'].get('资产型号9'),i['ext'].get('资产型号10')]:
             if j:
                 info['exp'].append({'label': j, 'score': score_threshold})
-        #判断i['ext']['BPO标注-AP-资产型号']是否为空，为空就不用读取，不为空就读取
-        if i['ext']['BPO标注-AP-资产型号']:
-            asset_name = i['ext']['BPO标注-AP-资产名称']
+        #判断i['ext']['资产型号']是否为空，为空就不用读取，不为空就读取
+        if i['ext']['资产型号']:
+            asset_name = i['ext']['资产名称']
             try:
                 if isinstance(asset_name, str):
                     asset_name = json.loads(asset_name)
@@ -448,18 +474,18 @@ def do_waterlevelline_autotest(collections, clientinfo, score_threshold):
                 # 若解析失败，说明不是 JSON 格式，保持原样
                 pass
         info['artificial'] = info['exp']
-        if i['ext']['BPO标注-AP-资产名称']:
-            asset_name = i['ext']['BPO标注-AP-资产名称']
+        if i['ext']['资产名称']:
+            asset_name = i['ext']['资产名称']
             try:
                 if isinstance(asset_name, str):
                     asset_name = json.loads(asset_name)
             except json.JSONDecodeError:
                 # 若解析失败，说明不是 JSON 格式，保持原样
                 pass
-            if "软件申请" in i['ext']['BPO标注-AP-分发技能']:
+            if "软件申请" in i['ext']['分发技能']:
                 keywprd = software_asset_sku_structure(asset_name)
                 res = json.loads(get_query_vector(keywprd, clientinfo))
-            if "设备/配件申请" in i['ext']['BPO标注-AP-分发技能']:
+            if "设备/配件申请" in i['ext']['分发技能']:
                 #keywprd = equipmentrequest_structure(asset_name, i['ext']['asset_type'])
                 keywprd = {
     "From": 0,
@@ -481,7 +507,7 @@ def do_waterlevelline_autotest(collections, clientinfo, score_threshold):
 }
                 res = json.loads(get_query_vector(keywprd, clientinfo))
                 #res = get_by_AssetModelBizTypes(keywprd,res0)
-            if "设备/配件退还" in i['ext']['BPO标注-AP-分发技能']:
+            if "设备/配件退还" in i['ext']['分发技能']:
                 keywprd = equipmentreturn_structure0(asset_name, i['ext']['asset_type'])
                 res0 = json.loads(get_query_vector(keywprd, clientinfo))
                 res = get_by_AssetModelBizTypes(keywprd, res0)
@@ -505,7 +531,7 @@ def do_waterlevelline_autotest_aseetspu(collections, clientinfo, score_threshold
             "用户输入/userInput": "我要申请软件，名字叫：ai_xzh_all_restricted_software完全受限软件"
         },
         "output": {
-            "用户输入/output": "我要申请软件，名字叫：ai_xzh_all_restricted_software完全受限软件"
+            "用户输出/output": "我要申请软件，名字叫：ai_xzh_all_restricted_software完全受限软件"
         },
         "rt": True,
         "label": [{"label": "GUI 软件申请", "score": 0.6}, {"label": "软件申请", "score": 0.5}],
@@ -515,22 +541,21 @@ def do_waterlevelline_autotest_aseetspu(collections, clientinfo, score_threshold
     }
     a =0
     for i in collections:
-        info['input']['用户输入/userInput'] = i['ext']['BPO标注-AP-资产名称']
-        info['output']['用户输入/output'] = i['ext']['BPO标注-AP-资产名称']
+        info['input']['用户输入/userInput'] = "用户对话："+i['ext']['用户输入']+",关键词提取："+i['ext']['资产名称']
+        info['output']['用户输出/output'] = i['ext']['资产名称']
         info['exp'] = []
-        for j in [i['ext']['BPO标注-AP-资产型号'], i['ext'].get('BPO标注-AP-资产型号1'),
-                  i['ext'].get('BPO标注-AP-资产型号2'), i['ext'].get('BPO标注-AP-资产型号3'),
-                  i['ext'].get('BPO标注-AP-资产型号4'), i['ext'].get('BPO标注-AP-资产型号5'),
-                  i['ext'].get('BPO标注-AP-资产型号6'), i['ext'].get('BPO标注-AP-资产型号7'),
-                  i['ext'].get('BPO标注-AP-资产型号8'), i['ext'].get('BPO标注-AP-资产型号9'),
-                  i['ext'].get('BPO标注-AP-资产型号10')]:
+        for j in [i['ext']['匹配型号1'], i['ext'].get('匹配型号2'),
+                  i['ext'].get('匹配型号3'), i['ext'].get('匹配型号4'),
+                  i['ext'].get('匹配型号5'), i['ext'].get('匹配型号6'),
+                  i['ext'].get('匹配型号7'), i['ext'].get('匹配型号8'),
+                  i['ext'].get('匹配型号9'), i['ext'].get('匹配型号10')]:
             if j:
                 info['exp'].append({'label': j, 'score': score_threshold})
         info['artificial'] = info['exp']
         info['label']=[]
-        if i['ext']['BPO标注-AP-资产名称']:
-            if "设备" in i['ext']['BPO标注-AP-分发技能'] or "配件" in i['ext']['BPO标注-AP-分发技能']:
-                asset_name = i['ext']['BPO标注-AP-资产名称']
+        if i['ext']['资产名称']:
+            if "设备&配件领用" in i['ext']['分发技能']:
+                asset_name = i['ext']['资产名称']
                 try:
                     # 尝试将其解析为 JSON 对象
                     if isinstance(asset_name, str):
@@ -540,11 +565,40 @@ def do_waterlevelline_autotest_aseetspu(collections, clientinfo, score_threshold
                     # 若解析失败，说明不是 JSON 格式，保持原样
                     pass
                 key = asset_name.get('asset_name') if isinstance(asset_name, dict) else asset_name
-                if i['ext']['BPO标注-AP-资产类型'] == "设备":
+                if i['ext']['资产类型'] == "设备":
                     hardtype = 1
-                elif  i['ext']['BPO标注-AP-资产类型'] == "配件" or  i['ext']['BPO标注-AP-资产类型'] == '2.0' :
+                elif  i['ext']['资产类型'] == "配件":
                     hardtype = 2
                 res = GetBestMatchItemonline(key,hardtype,clientinfo)
+            if "设备借用" in i['ext']['分发技能'] or "配件借用" in i['ext']['分发技能']:
+                asset_name = i['ext']['资产名称']
+                try:
+                    # 尝试将其解析为 JSON 对象
+                    if isinstance(asset_name, str):
+                        asset_name0 = json.loads(asset_name)
+                        asset_name = asset_name0['asset_name']
+                except json.JSONDecodeError:
+                    # 若解析失败，说明不是 JSON 格式，保持原样
+                    pass
+                key = asset_name.get('asset_name') if isinstance(asset_name, dict) else asset_name
+                if i['ext']['资产类型'] == "设备":
+                    hardtype = 1
+                elif  i['ext']['资产类型'] == "配件" or  i['ext']['资产类型'] == '2.0' :
+                    hardtype = 2
+                res = GetBestMatchItemonline_(key,hardtype,clientinfo)
+            if "软件申请" in i['ext']['分发技能']:
+                user_input_parts = [
+                    "用户对话："+i['ext'].get('用户输入', ''),
+                    "资产名称："+i['ext'].get('资产名称', ''),
+                    "版本："+i['ext'].get('版本', ''),
+                    "用途："+i['ext'].get('用途', '')
+                ]
+                info['input']['用户输入/userInput'] = ','.join(filter(None, user_input_parts))
+                key = asset_name = i['ext'].get('资产名称')
+                Description = i['ext'].get('版本') + i['ext'].get('用途')
+                res = GetBestMatchItemonline_software(key, Description, clientinfo)
+                hardtype = 100
+
         else:
             res = ""
         infoout = do_waterlevellineres_listassetspu(res, info,hardtype)
@@ -575,17 +629,17 @@ def do_waterlevelline_autotest_aseetspu_old(collections, clientinfo, score_thres
     }
     a =0
     for i in collections:
-        info['input']['用户输入/userInput'] = i['ext']['BPO标注-AP-资产名称']
-        info['output']['用户输入/output'] = i['ext']['BPO标注-AP-资产名称']
+        info['input']['用户输入/userInput'] = i['ext']['资产名称']
+        info['output']['用户输入/output'] = i['ext']['资产名称']
         info['exp'] = [
-            {'label': i['ext']['BPO标注-AP-资产型号'], 'score': score_threshold},
-            {'label': i['ext'].get('BPO标注-AP-资产型号1', ''), 'score': score_threshold}]
+            {'label': i['ext']['资产型号'], 'score': score_threshold},
+            {'label': i['ext'].get('资产型号1', ''), 'score': score_threshold}]
         info['artificial'] = info['exp']
         info['label']=[]
-        if i['ext']['BPO标注-AP-资产名称']:
-            if "设备" in i['ext']['BPO标注-AP-分发技能'] or "配件" in i['ext']['BPO标注-AP-分发技能']:
-                asset_name = i['ext']['BPO标注-AP-资产名称']
-                asset_name = i['ext']['BPO标注-AP-资产类型']
+        if i['ext']['资产名称']:
+            if "设备" in i['ext']['分发技能'] or "配件" in i['ext']['分发技能']:
+                asset_name = i['ext']['资产名称']
+                asset_name = i['ext']['资产类型']
                 try:
                     # 尝试将其解析为 JSON 对象
                     if isinstance(asset_name, str):
@@ -594,9 +648,9 @@ def do_waterlevelline_autotest_aseetspu_old(collections, clientinfo, score_thres
                     # 若解析失败，说明不是 JSON 格式，保持原样
                     pass
                 key = asset_name.get('asset_name') if isinstance(asset_name, dict) else asset_name
-                if i['ext']['BPO标注-AP-资产型号'] == "设备":
+                if i['ext']['资产型号'] == "设备":
                     hardtype = 1
-                elif  i['ext']['BPO标注-AP-资产型号'] == "配件" :
+                elif  i['ext']['资产型号'] == "配件" :
                     hardtype = 2
                 res = GetBestMatchItemonline_old(key,hardtype,clientinfo)
         else:
@@ -630,17 +684,21 @@ def do_waterlevelline_autotest_aseetspu_pre(collections, clientinfo, score_thres
     }
     a =0
     for i in collections:
-        info['input']['用户输入/userInput'] = i['ext']['BPO标注-AP-资产名称']
-        info['output']['用户输入/output'] = i['ext']['BPO标注-AP-资产名称']
-        info['exp'] = [
-            {'label': i['ext']['BPO标注-AP-资产型号'], 'score': score_threshold},
-            {'label': i['ext'].get('BPO标注-AP-资产型号1', ''), 'score': score_threshold}]
+        info['input']['用户输入/userInput'] = i['ext']['资产名称']
+        info['output']['用户输入/output'] = i['ext']['资产名称']
+        info['exp'] = []
+        for j in [i['ext']['匹配型号1'], i['ext'].get('匹配型号2'), i['ext'].get('匹配型号3'),
+                  i['ext'].get('匹配型号4'), i['ext'].get('匹配型号5'), i['ext'].get('匹配型号6'),
+                  i['ext'].get('匹配型号7'), i['ext'].get('匹配型号8'), i['ext'].get('匹配型号9'),
+                  i['ext'].get('匹配型号10')]:
+            if j:
+                info['exp'].append({'label': j, 'score': score_threshold})
         info['artificial'] = info['exp']
         info['label']=[]
-        if i['ext']['BPO标注-AP-资产名称']:
-            if "设备" in i['ext']['BPO标注-AP-分发技能'] or "配件" in i['ext']['BPO标注-AP-分发技能']:
-                asset_name = i['ext']['BPO标注-AP-资产名称']
-                asset_name = i['ext']['BPO标注-AP-资产类型']
+        if i['ext']['资产名称']:
+            if "设备&配件领用" in i['ext']['分发技能']:
+                asset_name = i['ext']['资产名称']
+                #asset_name = i['ext']['资产类型']
                 try:
                     # 尝试将其解析为 JSON 对象
                     if isinstance(asset_name, str):
@@ -649,14 +707,31 @@ def do_waterlevelline_autotest_aseetspu_pre(collections, clientinfo, score_thres
                     # 若解析失败，说明不是 JSON 格式，保持原样
                     pass
                 key = asset_name.get('asset_name') if isinstance(asset_name, dict) else asset_name
-                if i['ext']['BPO标注-AP-资产型号'] == "设备":
+                if i['ext']['资产类型'] == "设备":
                     hardtype = 1
-                elif  i['ext']['BPO标注-AP-资产型号'] == "配件" :
+                elif  i['ext']['资产类型'] == "配件" :
                     hardtype = 2
-                res = test_hardware_match(key,hardtype,clientinfo)
+                res = GetBestMatchItemoff(key,hardtype,clientinfo)
+
+            if "设备借用" in i['ext']['分发技能']:
+                asset_name = i['ext']['资产名称']
+                #asset_name = i['ext']['资产类型']
+                try:
+                    # 尝试将其解析为 JSON 对象
+                    if isinstance(asset_name, str):
+                        asset_name = json.loads(asset_name)
+                except json.JSONDecodeError:
+                    # 若解析失败，说明不是 JSON 格式，保持原样
+                    pass
+                key = asset_name.get('asset_name') if isinstance(asset_name, dict) else asset_name
+                if i['ext']['资产类型'] == "设备":
+                    hardtype = 1
+                elif  i['ext']['资产类型'] == "配件" :
+                    hardtype = 2
+                res = GetBestMatchItemoff0(key,hardtype,clientinfo)
         else:
             res = ""
-        infoout = do_waterlevellineres_listassetspu_pre(res, info,hardtype)
+        infoout = do_waterlevellineres_listassetspu(res, info,hardtype)
         info_list.append(copy.deepcopy(infoout))
         a = a+1
         print("这是"+str(a))
@@ -684,17 +759,17 @@ def do_waterlevelline_autotest_search(collections, clientinfo, score_threshold):
     }
     a =0
     for i in collections:
-        info['input']['用户输入/userInput'] = i['ext']['BPO标注-AP-资产名称']
-        info['output']['用户输入/output'] = i['ext']['BPO标注-AP-资产名称']
+        info['input']['用户输入/userInput'] = i['ext']['资产名称']
+        info['output']['用户输入/output'] = i['ext']['资产名称']
         info['exp'] = [
-            {'label': i['ext']['BPO标注-AP-资产型号'], 'score': score_threshold},
-            {'label': i['ext'].get('BPO标注-AP-资产型号1', ''), 'score': score_threshold}]
+            {'label': i['ext']['资产型号'], 'score': score_threshold},
+            {'label': i['ext'].get('资产型号1', ''), 'score': score_threshold}]
         info['artificial'] = info['exp']
         info['label']=[]
-        if i['ext']['BPO标注-AP-资产名称']:
-            if "设备" in i['ext']['BPO标注-AP-分发技能'] or "配件" in i['ext']['BPO标注-AP-分发技能']:
-                asset_name = i['ext']['BPO标注-AP-资产名称']
-                asset_name = i['ext']['BPO标注-AP-资产类型']
+        if i['ext']['资产名称']:
+            if "设备" in i['ext']['分发技能'] or "配件" in i['ext']['分发技能']:
+                asset_name = i['ext']['资产名称']
+                asset_name = i['ext']['资产类型']
                 try:
                     # 尝试将其解析为 JSON 对象
                     if isinstance(asset_name, str):
@@ -703,9 +778,9 @@ def do_waterlevelline_autotest_search(collections, clientinfo, score_threshold):
                     # 若解析失败，说明不是 JSON 格式，保持原样
                     pass
                 key = asset_name.get('asset_name') if isinstance(asset_name, dict) else asset_name
-                if i['ext']['BPO标注-AP-资产型号'] == "设备":
+                if i['ext']['资产型号'] == "设备":
                     hardtype = 1
-                elif  i['ext']['BPO标注-AP-资产型号'] == "配件" :
+                elif  i['ext']['资产型号'] == "配件" :
                     hardtype = 2
                 res = searchListAssetModelScope(key,hardtype,clientinfo)
         else:
@@ -739,24 +814,24 @@ def do_waterlevelline_autotest_SoftwareApplyRecommendList(collections, clientinf
     }
     a =0
     for i in collections:
-        info['input']['用户输入/userInput'] = i['ext'].get('BPO标注-AP-资产名称') or i['ext'].get('BPO标注-AP-资产名称')
-        info['output']['实际输出/output'] = i['ext']['BPO标注-AP-资产名称']
+        info['input']['用户输入/userInput'] = i['ext'].get('资产名称') or i['ext'].get('资产名称')
+        info['output']['实际输出/output'] = i['ext']['资产名称']
         info['exp'] = []
-        for j in [i['ext']['BPO标注-AP-资产型号'], i['ext'].get('BPO标注-AP-资产型号1'),
-                  i['ext'].get('BPO标注-AP-资产型号2'), i['ext'].get('BPO标注-AP-资产型号3'),
-                  i['ext'].get('BPO标注-AP-资产型号4'), i['ext'].get('BPO标注-AP-资产型号5'),
-                  i['ext'].get('BPO标注-AP-资产型号6'), i['ext'].get('BPO标注-AP-资产型号7'),
-                  i['ext'].get('BPO标注-AP-资产型号8'), i['ext'].get('BPO标注-AP-资产型号9'),
-                  i['ext'].get('BPO标注-AP-资产型号10')]:
+        for j in [i['ext']['资产型号'], i['ext'].get('资产型号1'),
+                  i['ext'].get('资产型号2'), i['ext'].get('资产型号3'),
+                  i['ext'].get('资产型号4'), i['ext'].get('资产型号5'),
+                  i['ext'].get('资产型号6'), i['ext'].get('资产型号7'),
+                  i['ext'].get('资产型号8'), i['ext'].get('资产型号9'),
+                  i['ext'].get('资产型号10')]:
             if j:
                 info['exp'].append({'label': j, 'score': score_threshold})
             if info['exp'] == '':
                 break
         info['artificial'] = info['exp']
         info['label']=[]
-        if i['ext']['BPO标注-AP-资产名称']:
-            if "软件" in i['ext']['BPO标注-AP-分发技能']:
-                asset_name = i['ext']['BPO标注-AP-资产名称']
+        if i['ext']['资产名称']:
+            if "软件" in i['ext']['分发技能']:
+                asset_name = i['ext']['资产名称']
                 try:
                     # 尝试将其解析为 JSON 对象
                     if isinstance(asset_name, str):
@@ -997,7 +1072,7 @@ def do_waterlevelline_autotest_fix(collections, clientinfo, score_threshold):
         for j in [i['ext']['匹配型号1'], i['ext'].get('匹配型号2'),i['ext'].get('匹配型号3'),i['ext'].get('匹配型号4'),i['ext'].get('匹配型号5'),i['ext'].get('匹配型号6'),i['ext'].get('匹配型号7'),i['ext'].get('匹配型号8'),i['ext'].get('匹配型号9'),i['ext'].get('匹配型号10')]:
             if j:
                 info['exp'].append({'label': j, 'score': score_threshold})
-        #判断i['ext']['BPO标注-AP-资产型号']是否为空，为空就不用读取，不为空就读取
+        #判断i['ext']['资产型号']是否为空，为空就不用读取，不为空就读取
         if i['ext']['资产名称']:
             asset_name = i['ext']['资产名称']
             try:
